@@ -122,7 +122,7 @@
   </section>
 </chapter>
 
-   $Date: 2014-04-28 07:51:36 +0100 (Mon, 28 Apr 2014) $ $Revision: 37818 $
+   $Date: 2016-04-25 12:08:15 +0100 (Mon, 25 Apr 2016) $ $Revision: 39692 $
    */ 
 
 #ifndef	INCLUDED_WEBSERVER_H
@@ -232,43 +232,6 @@
 - (BOOL) processRequest: (WebServerRequest*)request
 	       response: (WebServerResponse*)response
 		    for: (WebServer*)http;
-/**
- * Log an error or warning ... if the delegate does not implement this
- * method, the message is logged to stderr using the NSLog function.
- */
-- (void) webAlert: (NSString*)message for: (WebServer*)http;
-
-/**
- * Log an audit record ... if the delegate does not implement this
- * method, the message is logged to stderr.<br />
- * The logged record is similar to the Apache common log format,
- * though it differs after the timestamp:
- * <deflist>
- *   <term>ip address</term>
- *   <desc>the address of the client host making the request</desc>
- *   <term>ident</term>
- *   <desc>not currently implemented ... '-' as placeholder</desc>
- *   <term>ident</term>
- *   <desc>not currently implemented ... '-' as placeholder</desc>
- *   <term>user</term>
- *   <desc>the remote user name from the authorization header, or '-'</desc>
- *   <term>timestamp</term>
- *   <desc>the date/time enclosed in square brackets</desc>
- *   <term>command</term>
- *   <desc>The command sent in the request ... as a quoted string</desc>
- *   <term>agent</term>
- *   <desc>The user-agent header from the request ... as a quoted string</desc>
- *   <term>result</term>
- *   <desc>The initial response line ... as a quoted string</desc>
- * </deflist>
- */
-- (void) webAudit: (NSString*)message for: (WebServer*)http;
-
-/**
- * Log a debug ... if the delegate does not implement this
- * method, no logging is done.
- */
-- (void) webLog: (NSString*)message for: (WebServer*)http;
 @end
 
 
@@ -334,8 +297,56 @@
 	          response: (WebServerResponse*)response
 		       for: (WebServer*)http;
 
+/**
+ * Log an error or warning ... if the delegate does not implement this
+ * method, the message is logged to stderr using the NSLog function.
+ */
+- (void) webAlert: (NSString*)message for: (WebServer*)http;
+
+/**
+ * Log an audit record ... if the delegate does not implement this
+ * method, the message is logged to stderr.<br />
+ * The logged record is similar to the Apache common log format,
+ * though it differs after the timestamp:
+ * <deflist>
+ *   <term>ip address</term>
+ *   <desc>the address of the client host making the request</desc>
+ *   <term>ident</term>
+ *   <desc>not currently implemented ... '-' as placeholder</desc>
+ *   <term>ident</term>
+ *   <desc>not currently implemented ... '-' as placeholder</desc>
+ *   <term>user</term>
+ *   <desc>the remote user name from the authorization header, or '-'</desc>
+ *   <term>timestamp</term>
+ *   <desc>the date/time enclosed in square brackets</desc>
+ *   <term>command</term>
+ *   <desc>The command sent in the request ... as a quoted string</desc>
+ *   <term>agent</term>
+ *   <desc>The user-agent header from the request ... as a quoted string</desc>
+ *   <term>result</term>
+ *   <desc>The initial response line ... as a quoted string</desc>
+ * </deflist>
+ */
+- (void) webAudit: (NSString*)message for: (WebServer*)http;
+
+/**
+ * Log a debug ... if the delegate does not implement this
+ * method, no logging is done.
+ */
+- (void) webLog: (NSString*)message for: (WebServer*)http;
+
 @end
 
+/*
+ * For interoperability with ARC code, we must tag the two unused id*
+ * instance variables as not participating in ARC.
+ */
+#if __has_feature(objc_arc)
+#define UNUSED_QUAL __unsafe_unretained
+#else
+#define UNUSED_QUAL
+#endif
+
 /**
  * <p>You create an instance of the WebServer class in order to handle
  * incoming HTTP or HTTPS requests on a single port.
@@ -397,8 +408,8 @@
   NSMutableArray	*_ioThreads;
   GSThreadPool		*_pool;
   WebServerConfig	*_conf;
-  id		        *_unused1;
-  id		        *_unused2;
+  id		        UNUSED_QUAL *_unused1;
+  id		        UNUSED_QUAL *_unused2;
   NSDictionary		*_sslConfig;
   BOOL			_accepting;
   BOOL			_doPostProcess;
